/*++

Copyright (c) 2009
Lysann Kessler, Stephanie Platz, Thomas Klingbeil, Philipp Tessenow, Frank Schlegel;
Michael Haupt, Michael Perscheid, Robert Hirschfeld;
Software Architecture Group, Hasso-Plattner-Institut, University of Potsdam, Germany

This software is published under MIT license.
It uses phidget library by Phidgets Inc. (http://phidgets.com).
See ../../../../license.pdf for more information.

--*/

#ifndef _PHIDGET_H_
#define _PHIDGET_H_

typedef struct _Phidget Phidget;

#include "PhidgetPlugin.h"

//
// General Phidget-struct.
// Contains a handle of the Phidget, a unique id that is given to the Squeak environment,
// a pointer to the next id in the global list, and semaphores which are common for all Phidgets.
//

struct _Phidget {
	CPhidgetHandle handle;				// handle provided by phidget21 library upon creation
	PhidgetId id;						// timestamp of object creation to provide unique identifier
	CPhidget_DeviceClass deviceClass;	// the Phidget's type
	Phidget* pNextLink;					// pointer to next Phidget in the Plugin's global Phidgets list
	int iSemaphoreAttach;				// semaphore index for Phidget attachment
	int iSemaphoreDetach;				// semaphore index for Phidget detachment
	int iSemaphoreError;				// semaphore index for errors in Phidgets
};

// static methods
int phidget_LastError();

// methods
sqInt phidget_Create(Phidget* pPhidget);
void phidget_ResetSemaphores(Phidget *pPhidget);
BOOL phidget_Open(PhidgetId id, int iSerialNumber);
BOOL phidget_OpenSpecific(Phidget* pPhidget);
BOOL phidget_Open_Base(Phidget* pPhidget);
BOOL phidget_Close(PhidgetId id);
BOOL phidget_Close_Base(Phidget* pPhidget);

BOOL phidget_SetSemaphoreIndex_Attach(PhidgetId id, int iSemaphoreIndex);
BOOL phidget_SetSemaphoreIndex_Detach(PhidgetId id, int iSemaphoreIndex);
BOOL phidget_SetSemaphoreIndex_Error(PhidgetId id, int iSemaphoreIndex);

BOOL phidget_getDeviceName(PhidgetId id, const char** ppcName, int* piNameSize);
BOOL phidget_getSerialNumber(PhidgetId id, int* piSerialNumber);
BOOL phidget_getLabel(PhidgetId id, const char** ppcLabel, int* piLabelSize);
BOOL phidget_getDeviceClass(PhidgetId id, CPhidget_DeviceClass* pClass);
BOOL phidget_getDeviceType(PhidgetId id, CPhidget_DeviceID* pDeviceID);
//int phidget_getSerialNumber(PhidgetId id);
BOOL phidget_isAttached(PhidgetId id);
BOOL phidget_isValid(PhidgetId id);

#endif //_PHIDGET_H_
